********
Citation
********

If you would like to cite KerasLMU in your research, please cite `this
paper <http://compneuro.uwaterloo.ca/files/publications/voelker.2019.lmu.pdf>`_:

   Aaron R. Voelker, Ivana Kajić, and Chris Eliasmith. Legendre Memory Units:
   Continuous-time representation in recurrent neural networks. In Advances in Neural
   Information Processing Systems, 15544–15553. 2019.

A BibTeX entry for LaTeX users is:

.. code-block:: tex

   @inproceedings{voelker2019lmu,
     title={Legendre Memory Units: Continuous-Time Representation in Recurrent Neural Networks},
     author={Aaron R. Voelker and Ivana Kaji\'c and Chris Eliasmith},
     booktitle={Advances in Neural Information Processing Systems},
     pages={15544--15553},
     year={2019}
   }
